==> cargo-binstall-1.16.5-1.src.tar.gz: cargo-binstall-1.16.5/crates/binstalk-registry/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.11.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.22...binstalk-registry-v0.11.23) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.21...binstalk-registry-v0.11.22) - 2025-07-25

### Other

- *(deps)* bump the deps group with 2 updates ([#2227](https://github.com/cargo-bins/cargo-binstall/pull/2227))
- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.11.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.30...binstalk-registry-v0.11.31) - 2025-12-20

### Other

- *(deps)* bump toml_edit from 0.23.10+spec-1.0.0 to 0.24.0+spec-1.1.0 in the deps group ([#2404](https://github.com/cargo-bins/cargo-binstall/pull/2404))
- Replace doc_auto_cfg with doc_cfg ([#2402](https://github.com/cargo-bins/cargo-binstall/pull/2402))

## [0.11.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.29...binstalk-registry-v0.11.30) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.11.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.28...binstalk-registry-v0.11.29) - 2025-11-23

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.27...binstalk-registry-v0.11.28) - 2025-11-15

### Other

- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader

## [0.11.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.26...binstalk-registry-v0.11.27) - 2025-11-09

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.25...binstalk-registry-v0.11.26) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.24...binstalk-registry-v0.11.25) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.11.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.23...binstalk-registry-v0.11.24) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.20...binstalk-registry-v0.11.21) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

## [0.11.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.19...binstalk-registry-v0.11.20) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.18...binstalk-registry-v0.11.19) - 2025-05-16

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.17...binstalk-registry-v0.11.18) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.16...binstalk-registry-v0.11.17) - 2025-03-19

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.15...binstalk-registry-v0.11.16) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.11.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.14...binstalk-registry-v0.11.15) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.11.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.13...binstalk-registry-v0.11.14) - 2025-02-28

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.12...binstalk-registry-v0.11.13) - 2025-02-11

### Other

- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader

## [0.11.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.11...binstalk-registry-v0.11.12) - 2025-02-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.10...binstalk-registry-v0.11.11) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.11.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.9...binstalk-registry-v0.11.10) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.11.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.8...binstalk-registry-v0.11.9) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.11.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.7...binstalk-registry-v0.11.8) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.11.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.6...binstalk-registry-v0.11.7) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.11.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.5...binstalk-registry-v0.11.6) - 2024-12-07

### Other

- updated the following local packages: cargo-toml-workspace

## [0.11.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.4...binstalk-registry-v0.11.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.11.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.3...binstalk-registry-v0.11.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.11.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.2...binstalk-registry-v0.11.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.11.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.1...binstalk-registry-v0.11.2) - 2024-11-02

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.0...binstalk-registry-v0.11.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.10.0...binstalk-registry-v0.11.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader

==> cargo-binstall-1.16.6-1.src.tar.gz: cargo-binstall-1.16.6/crates/binstalk-registry/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.11.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.22...binstalk-registry-v0.11.23) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.21...binstalk-registry-v0.11.22) - 2025-07-25

### Other

- *(deps)* bump the deps group with 2 updates ([#2227](https://github.com/cargo-bins/cargo-binstall/pull/2227))
- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.11.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.31...binstalk-registry-v0.11.32) - 2025-12-27

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.30...binstalk-registry-v0.11.31) - 2025-12-20

### Other

- *(deps)* bump toml_edit from 0.23.10+spec-1.0.0 to 0.24.0+spec-1.1.0 in the deps group ([#2404](https://github.com/cargo-bins/cargo-binstall/pull/2404))
- Replace doc_auto_cfg with doc_cfg ([#2402](https://github.com/cargo-bins/cargo-binstall/pull/2402))

## [0.11.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.29...binstalk-registry-v0.11.30) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.11.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.28...binstalk-registry-v0.11.29) - 2025-11-23

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.27...binstalk-registry-v0.11.28) - 2025-11-15

### Other

- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader

## [0.11.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.26...binstalk-registry-v0.11.27) - 2025-11-09

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.25...binstalk-registry-v0.11.26) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.24...binstalk-registry-v0.11.25) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.11.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.23...binstalk-registry-v0.11.24) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.20...binstalk-registry-v0.11.21) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

## [0.11.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.19...binstalk-registry-v0.11.20) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.18...binstalk-registry-v0.11.19) - 2025-05-16

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.17...binstalk-registry-v0.11.18) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.16...binstalk-registry-v0.11.17) - 2025-03-19

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.15...binstalk-registry-v0.11.16) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.11.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.14...binstalk-registry-v0.11.15) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.11.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.13...binstalk-registry-v0.11.14) - 2025-02-28

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.12...binstalk-registry-v0.11.13) - 2025-02-11

### Other

- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader

## [0.11.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.11...binstalk-registry-v0.11.12) - 2025-02-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.10...binstalk-registry-v0.11.11) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.11.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.9...binstalk-registry-v0.11.10) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.11.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.8...binstalk-registry-v0.11.9) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.11.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.7...binstalk-registry-v0.11.8) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.11.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.6...binstalk-registry-v0.11.7) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.11.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.5...binstalk-registry-v0.11.6) - 2024-12-07

### Other

- updated the following local packages: cargo-toml-workspace

## [0.11.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.4...binstalk-registry-v0.11.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.11.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.3...binstalk-registry-v0.11.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.11.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.2...binstalk-registry-v0.11.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.11.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.1...binstalk-registry-v0.11.2) - 2024-11-02

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.11.0...binstalk-registry-v0.11.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.11.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-registry-v0.10.0...binstalk-registry-v0.11.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader
